[llvm-commits] CVS: llvm/lib/Target/IA64/IA64TargetMachine.cpp IA64TargetMachine.h

Chris Lattner lattner at cs.uiuc.edu
Fri Jun 24 19:48:49 PDT 2005



Changes in directory llvm/lib/Target/IA64:

IA64TargetMachine.cpp updated: 1.3 -> 1.4
IA64TargetMachine.h updated: 1.2 -> 1.3
---
Log message:

Refactor the addPassesToEmitAssembly interface into a addPassesToEmitFile
interface.


---
Diffs of the changes:  (+8 -4)

 IA64TargetMachine.cpp |    9 ++++++---
 IA64TargetMachine.h   |    3 ++-
 2 files changed, 8 insertions(+), 4 deletions(-)


Index: llvm/lib/Target/IA64/IA64TargetMachine.h
diff -u llvm/lib/Target/IA64/IA64TargetMachine.h:1.2 llvm/lib/Target/IA64/IA64TargetMachine.h:1.3
--- llvm/lib/Target/IA64/IA64TargetMachine.h:1.2	Thu Apr 21 18:13:11 2005
+++ llvm/lib/Target/IA64/IA64TargetMachine.h	Fri Jun 24 21:48:36 2005
@@ -35,7 +35,8 @@
     return &InstrInfo.getRegisterInfo();
   }
 
-  virtual bool addPassesToEmitAssembly(PassManager &PM, std::ostream &Out);
+  virtual bool addPassesToEmitFile(PassManager &PM, std::ostream &Out,
+                                   CodeGenFileType FileType);
 
   static unsigned getModuleMatchQuality(const Module &M);
   static unsigned compileTimeMatchQuality(void);






More information about the llvm-commits mailing list
Index: llvm/lib/Target/IA64/IA64TargetMachine.cpp
diff -u llvm/lib/Target/IA64/IA64TargetMachine.cpp:1.3 llvm/lib/Target/IA64/IA64TargetMachine.cpp:1.4
--- llvm/lib/Target/IA64/IA64TargetMachine.cpp:1.3	Fri Apr 22 12:54:15 2005
+++ llvm/lib/Target/IA64/IA64TargetMachine.cpp	Fri Jun 24 21:48:36 2005
@@ -77,10 +77,13 @@
     FrameInfo(TargetFrameInfo::StackGrowsDown, 16, 0) { // FIXME? check this stuff
 }
 
 // addPassesToEmitAssembly - We currently use all of the same passes as the JIT
 // does to emit statically compiled machine code.
-bool IA64TargetMachine::addPassesToEmitAssembly(PassManager &PM,
-                                                std::ostream &Out) {
+bool IA64TargetMachine::addPassesToEmitFile(PassManager &PM,
+                                            std::ostream &Out,
+                                                CodeGenFileType FileType) {
+  if (FileType != TargetMachine::AssemblyFile) return true;
+
   // FIXME: Implement efficient support for garbage collection intrinsics.
   PM.add(createLowerGCPass());
 
@@ -77,10 +77,13 @@
 }
 
-// addPassesToEmitAssembly - We currently use all of the same passes as the JIT
+// addPassesToEmitFile - We currently use all of the same passes as the JIT
 // does to emit statically compiled machine code.

